# Reference

Technical reference material including APIs and release notes.

```{toctree}
:maxdepth: 1
:glob:

API <_api/tickit_devices>
genindex
Release Notes <https://github.com/DiamondLightSource/tickit-devices/releases>
```
